
create table bmsql_config (
  cfg_name    varchar(30) primary key,
  cfg_value   varchar(50)
);

create table bmsql_warehouse (
  w_id        integer   not null,
  w_ytd       decimal(12,2),
  w_tax       decimal(4,4),
  w_name      varchar(10),
  w_street_1  varchar(20),
  w_street_2  varchar(20),
  w_city      varchar(20),
  w_state     char(2),
  w_zip       char(9)
);

create table bmsql_district (
  d_w_id       integer       not null,
  d_id         integer       not null,
  d_ytd        decimal(12,2),
  d_tax        decimal(4,4),
  d_next_o_id  integer,
  d_name       varchar(10),
  d_street_1   varchar(20),
  d_street_2   varchar(20),
  d_city       varchar(20),
  d_state      char(2),
  d_zip        char(9)
) extent size 128 next size 32;

-- fragment by c_w_id -- c_d_id, c_id
create table bmsql_customer (
  c_w_id         integer        not null,
  c_d_id         integer        not null,
  c_id           integer        not null,
  c_discount     decimal(4,4),
  c_credit       char(2),
  c_last         varchar(16),
  c_first        varchar(16),
  c_credit_lim   decimal(12,2),
  c_balance      decimal(12,2),
  c_ytd_payment  decimal(12,2),
  c_payment_cnt  integer,
  c_delivery_cnt integer,
  c_street_1     varchar(20),
  c_street_2     varchar(20),
  c_city         varchar(20),
  c_state        char(2),
  c_zip          char(9),
  c_phone        char(16),
  c_since        timestamp,
  c_middle       char(2),
  c_data         char(500)
)
FRAGMENT BY EXPRESSION
  mod(c_w_id,10) = 1 in datadbs01,
  mod(c_w_id,10) = 2 in datadbs02,
  mod(c_w_id,10) = 3 in datadbs03,
  mod(c_w_id,10) = 4 in datadbs04,
  mod(c_w_id,10) = 5 in datadbs05,
  mod(c_w_id,10) = 6 in datadbs06,
  mod(c_w_id,10) = 7 in datadbs07,
  mod(c_w_id,10) = 8 in datadbs08,
  mod(c_w_id,10) = 9 in datadbs09,
  mod(c_w_id,10) = 0 in datadbs10
extent size 40000 next size 40000;

create sequence bmsql_hist_id_seq;

-- fragment by h_w_id
create table bmsql_history (
  hist_id  bigserial,
  h_c_id   integer,
  h_c_d_id integer,
  h_c_w_id integer,
  h_d_id   integer,
  h_w_id   integer,
  h_date   timestamp,
  h_amount decimal(6,2),
  h_data   varchar(24)
)
FRAGMENT BY EXPRESSION
  mod(hist_id,10) = 1 in datadbs01,
  mod(hist_id,10) = 2 in datadbs02,
  mod(hist_id,10) = 3 in datadbs03,
  mod(hist_id,10) = 4 in datadbs04,
  mod(hist_id,10) = 5 in datadbs05,
  mod(hist_id,10) = 6 in datadbs06,
  mod(hist_id,10) = 7 in datadbs07,
  mod(hist_id,10) = 8 in datadbs08,
  mod(hist_id,10) = 9 in datadbs09,
  mod(hist_id,10) = 0 in datadbs10
extent size 40000 next size 8000;

-- fragment by no_w_id -- no_d_id, no_o_id
create table bmsql_new_order (
  no_w_id  integer   not null,
  no_d_id  integer   not null,
  no_o_id  integer   not null
)
FRAGMENT BY EXPRESSION
  mod(no_w_id,10) = 1 in datadbs01,
  mod(no_w_id,10) = 2 in datadbs02,
  mod(no_w_id,10) = 3 in datadbs03,
  mod(no_w_id,10) = 4 in datadbs04,
  mod(no_w_id,10) = 5 in datadbs05,
  mod(no_w_id,10) = 6 in datadbs06,
  mod(no_w_id,10) = 7 in datadbs07,
  mod(no_w_id,10) = 8 in datadbs08,
  mod(no_w_id,10) = 9 in datadbs09,
  mod(no_w_id,10) = 0 in datadbs10
extent size 40000 next size 8000;

-- fragment by o_w_id -- o_d_id, o_id
create table bmsql_oorder (
  o_w_id       integer      not null,
  o_d_id       integer      not null,
  o_id         integer      not null,
  o_c_id       integer,
  o_carrier_id integer,
  o_ol_cnt     integer,
  o_all_local  integer,
  o_entry_d    timestamp
)
FRAGMENT BY EXPRESSION
  mod(o_w_id,10) = 1 in datadbs01,
  mod(o_w_id,10) = 2 in datadbs02,
  mod(o_w_id,10) = 3 in datadbs03,
  mod(o_w_id,10) = 4 in datadbs04,
  mod(o_w_id,10) = 5 in datadbs05,
  mod(o_w_id,10) = 6 in datadbs06,
  mod(o_w_id,10) = 7 in datadbs07,
  mod(o_w_id,10) = 8 in datadbs08,
  mod(o_w_id,10) = 9 in datadbs09,
  mod(o_w_id,10) = 0 in datadbs10
extent size 40000 next size 8000;

-- fragment by ol_w_id -- ol_d_id, ol_o_id, ol_number
create table bmsql_order_line (
  ol_w_id         integer   not null,
  ol_d_id         integer   not null,
  ol_o_id         integer   not null,
  ol_number       integer   not null,
  ol_i_id         integer   not null,
  ol_delivery_d   timestamp,
  ol_amount       decimal(6,2),
  ol_supply_w_id  integer,
  ol_quantity     integer,
  ol_dist_info    char(24)
)
FRAGMENT BY EXPRESSION
  mod(ol_w_id,10) = 1 in datadbs01,
  mod(ol_w_id,10) = 2 in datadbs02,
  mod(ol_w_id,10) = 3 in datadbs03,
  mod(ol_w_id,10) = 4 in datadbs04,
  mod(ol_w_id,10) = 5 in datadbs05,
  mod(ol_w_id,10) = 6 in datadbs06,
  mod(ol_w_id,10) = 7 in datadbs07,
  mod(ol_w_id,10) = 8 in datadbs08,
  mod(ol_w_id,10) = 9 in datadbs09,
  mod(ol_w_id,10) = 0 in datadbs10
extent size 400000 next size 80000;

--
create table bmsql_item (
  i_id     integer      not null,
  i_name   varchar(24),
  i_price  decimal(5,2),
  i_data   varchar(50),
  i_im_id  integer
) extent size 8000 next size 2000;

-- fragment by s_w_id --s_i_id
create table bmsql_stock (
  s_w_id       integer       not null,
  s_i_id       integer       not null,
  s_quantity   integer,
  s_ytd        integer,
  s_order_cnt  integer,
  s_remote_cnt integer,
  s_data       varchar(50),
  s_dist_01    char(24),
  s_dist_02    char(24),
  s_dist_03    char(24),
  s_dist_04    char(24),
  s_dist_05    char(24),
  s_dist_06    char(24),
  s_dist_07    char(24),
  s_dist_08    char(24),
  s_dist_09    char(24),
  s_dist_10    char(24)
)
FRAGMENT BY EXPRESSION
  mod(s_w_id,10) = 1 in datadbs01,
  mod(s_w_id,10) = 2 in datadbs02,
  mod(s_w_id,10) = 3 in datadbs03,
  mod(s_w_id,10) = 4 in datadbs04,
  mod(s_w_id,10) = 5 in datadbs05,
  mod(s_w_id,10) = 6 in datadbs06,
  mod(s_w_id,10) = 7 in datadbs07,
  mod(s_w_id,10) = 8 in datadbs08,
  mod(s_w_id,10) = 9 in datadbs09,
  mod(s_w_id,10) = 0 in datadbs10
extent size 40000 next size 40000;


